@@ -9,12 +9,14 @@
 calculate_share_non_row_wise <- function(dat = NULL) {
   if (any(class(dat) == "data.table")) {
     # Generate necessary variables --------------------------------------------
-    na_count <- vapply(dat, function(y)
+    na_count <- vapply(dat, function(y) {
       sum(length(which(is.na(
         y
-      )))), FUN.VALUE = numeric(1))
-    total <- vapply(dat, function(y)
-      length(y), FUN.VALUE = numeric(1))
+      ))))
+    }, FUN.VALUE = numeric(1))
+    total <- vapply(dat, function(y) {
+      length(y)
+    }, FUN.VALUE = numeric(1))
 
     dat_result <- data.table(na_count, total)
 
@@ -26,12 +28,14 @@ calculate_share_non_row_wise <- function(dat = NULL) {
     dat_result <- dat_result[, list(percentage = na_count / (total / 100))]
   } else {
     # Generate necessary variables --------------------------------------------
-    na_count <- vapply(dat, function(y)
+    na_count <- vapply(dat, function(y) {
       sum(length(which(is.na(
         y
-      )))), FUN.VALUE = numeric(1))
-    total <- vapply(dat, function(y)
-      length(y), FUN.VALUE = numeric(1))
+      ))))
+    }, FUN.VALUE = numeric(1))
+    total <- vapply(dat, function(y) {
+      length(y)
+    }, FUN.VALUE = numeric(1))
 
     dat_result <- data.frame(na_count, total)
     # Add rownames as variable
